function [head,nw,wv,spec]=ReadOOIfile(dirn,fname)
% [head,nw,wv,lt]=ReadOOIfile(dirn,filename);
% read, smooth, cut to 300-700nm every 2nm, for OOI USB2000+ output spectra
% DATA:  dirn : scan file directory, such as 'C:\Scans\'
%        fname: scan file name 
% OUTPUT:
%   head: file name, 'date & time', integ. time, n averaged, boxcar
%     nw: points in scan    wv = wavelengths    spec = spectrum output
wv=(300:1:700)'; n=length(wv);
fnm=[dirn fname];
fid=fopen(fnm);
rd=textscan(fid,'%s',17,'whitespace','\n'); heads=rd{1};
% heads contains first 17 rows of file--OOI scan parameters
%   extract=date,  integration time,  averaged,  boxcar
rd=textscan(fid,'%f %f');
fclose(fid); 
rwv=rd{1}; rlt=rd{2}; clear fnm fid rd;
datestr=''; IT=''; AV=''; BX='';
for i=1:17
  str=heads{i};
  k=strfind(str,'Date'); if isempty(k) k=0; end;
  if k>0 datestr=str; datestr(1:6)=[]; end;
  k=strfind(str,'Integration'); if isempty(k) k=0; end;
  if k>0 
    str(1:25)=[]; str=strtrim(str);
    k1=strfind(str,' '); if isempty(k1) k1=0; end; k1=k1-1;
    str=str(1:k1); IT=strtrim(str); 
  end;
  k=strfind(str,'Averaged'); if isempty(k) k=0; end;
  if k>0 
    str(1:17)=[]; str=strtrim(str); 
    k1=strfind(str,' '); if isempty(k1) k1=0; end; k1=k1-1;
    str=str(1:k1); AV=strtrim(str); 
  end;
  k=strfind(str,'Boxcar'); if isempty(k) k=0; end;
  if k>0 
    str(1:17)=[]; str=strtrim(str); 
    k1=strfind(str,' '); if isempty(k1) k1=0; end; k1=k1-1;
    str=str(1:k1); BX=strtrim(str);
  end;
end;
head=[fname ' ''' datestr ''' ' IT ' ' AV ' ' BX];
clear fname datestr heads k k1 rd str IT AV BX;
% now smooth to the nearest nm (29 point moving average of raw data)
span=20; ltr=smooth(rlt,span); lt=pchip(rwv,ltr,wv); %extract 2nm points
nw=n; spec=lt;
end




