function [hd,uv,sw,mw,lw,ct,lum,lm,ls,lu,ms,mu,su,tx,ty,tz]=Spec2ToBirdEye(wv,spec,etype)
% [hd,uv,sw,mw,lw,ct,lum,lm,ls,lu,ms,mu,su,tx,ty,tz]=Spec2ToBirdEye(wv,spec,etype);
% converts 2nm spectrum in spec to bird eye parameters
%            [such as output of ReadOOIfile(directory,filename)]
%   Uses bird eye models, data in BirdEyes201wv.txt; this file has to be in the same
%         directory as this function, or modify the fn='BirdEyes201wv.txt' to includ path.
%   Uses function: ToTet(uv,sw,mw,lw)
%   This version assumes white light (same results as old GETSPACE.PAS)
%INPUT: wv     wavelengths 300-700 in 2nm steps
%       spec   spectrum    300-700 in 2nm steps
%       etype  eye type =1 for V-type  =2 for U-type bird eye (default=1)
%OUTPUT: hd           eye type text for file heading
%        uv,sw,mw,lw  relative cone captures (add to 1.0) for each scan
%        ct,lum       ct=sum of cone captures, lum=capture of double cone
%        mu,ls,lm..   lsmu colour space coordinates
%        tx,ty,tz     tetrahedral coordinates of uv,sw,mw,lw
%
if nargin==2 etype=1; end;
[i,j]=size(spec); if i==1 spec=spec'; end; %make sure it is a column vector
[i,j]=size(wv); if i==1 wv=wv'; end;
[n,i]=size(wv); %n = number of wavelengths
%read bird eye model
fn='BirdEyes201wv.txt';
[wv2,uuv,usw,umw,ulw,vuv,vsw,vmw,vlw,dbc]=textread(fn,...
    '%f %f %f %f %f %f %f %f %f %f','headerlines',3);
[n2,i]=size(wv2); 
if n~=n2
  fprintf(1,'Spectrum file has %d wavelengths, not %d in eye model\n',n,n2);
end;
if etype==1 
    hd=['v-type eye'];
else
    hd=['u-type eye'];
end;
% fprintf(1,'%s\n',hd);
    %correct for negative drift
    mns=min(spec); 
    if mns<0 
      spec=spec-mns;
    end;
    %bird eye times light
    if etype==1
        tuv=vuv'*spec; tsw=vsw'*spec; tmw=vmw'*spec; tlw=vlw'*spec;
    else
        tuv=uuv'*spec; tsw=usw'*spec; tmw=umw'*spec; tlw=ulw'*spec;
    end;
    lum=dbc'*spec;  %double cone luminance estimate
    %separate luminance and color channels
    qt=tuv+tsw+tmw+tlw; ct=qt;
    tuv=tuv/qt; tsw=tsw/qt; tmw=tmw/qt; tlw=tlw/qt;
    uv=tuv; sw=tsw; mw=tmw; lw=tlw;
    %get ls mu and other colour space coordinates
    lm=(tlw-tmw)/(tlw+tmw); ls=(tlw-tsw)/(tlw+tsw); 
    lu=(tlw-tuv)/(tlw+tuv); ms=(tmw-tsw)/(tmw+tsw);
    mu=(tmw-tuv)/(tmw+tuv); su=(tsw-tuv)/(tsw+tuv);
    [xt,yt,zt]=ToTet(tuv,tsw,tmw,tlw);
    tx=xt; ty=yt; tz=zt;
end
